@@ -19,6 +19,7 @@
 
 
 #include "utils.h"
+#include "dsettings.h"
 
 #include <QRegularExpression>
 #include <QStandardPaths>
@@ -69,6 +70,8 @@ QString Utils::getQssContent(const QString &filePath)
  */
 QString Utils::formatThousandsSeparators(const QString &str)
 {
+    int separate = DSettingsAlt::instance()->getSeparate(); //数字分割位数
+
     QString result = str;
     int startPos = result.indexOf(QRegularExpression("[0-9]"));
     if (startPos >= 0) {
@@ -80,7 +83,7 @@ QString Utils::formatThousandsSeparators(const QString &str)
                 endPos = result.length();
         }
 
-        for (int i = endPos - 3; i >= startPos + 1; i -= 3) {
+        for (int i = endPos - separate; i >= startPos + 1; i -= separate) {
             result.insert(i, ",");
         }
     }
@@ -146,6 +149,8 @@ QString Utils::reformatSeparators(const QString &exp)
 
 QString Utils::formatThousandsSeparatorsPro(const QString &str, const int Base)
 {
+
+
     QString result = str;
     int startPos = result.indexOf(QRegularExpression("[0-9]"));
     int startPosHex = result.indexOf(QRegularExpression("[A-F0-9]"));
@@ -162,7 +167,8 @@ QString Utils::formatThousandsSeparatorsPro(const QString &str, const int Base)
     case 10:
         if (startPos >= 0) {
             int endPos  = result.length();
-            for (int i = endPos - 3; i >= startPos + 1; i -= 3) {
+            int separate = DSettingsAlt::instance()->getSeparate(); //数字分割位数
+            for (int i = endPos - separate; i >= startPos + 1; i -= separate) {
                 result.insert(i, ",");
             }
         }
