@@ -1145,6 +1145,7 @@ void ExpressionBar::initConnect()
     connect(m_inputEdit, &InputEdit::undo, this, &ExpressionBar::Undo);
     connect(m_inputEdit, &InputEdit::redo, this, &ExpressionBar::Redo);
     connect(m_inputEdit, &InputEdit::setResult, this, &ExpressionBar::setResultFalse);
+    connect(m_inputEdit, &InputEdit::separateChange, this, &ExpressionBar::onSeparateChange);
 }
 
 /**
@@ -1544,3 +1545,12 @@ InputEdit *ExpressionBar::getInputEdit()
 {
     return m_inputEdit;
 }
+
+/**
+ * @brief ExpressionBar::separateChange
+ * 数字间隔位数发生改变
+ */
+void ExpressionBar::onSeparateChange()
+{
+   m_listModel->updataOfSeparate();
+}
